@@ -580,7 +580,7 @@ module Msf::Post::File
     if session.type == 'meterpreter' && session.commands.include?(Rex::Post::Meterpreter::Extensions::Stdapi::COMMAND_ID_STDAPI_FS_CHMOD)
       session.fs.file.chmod(path, mode)
     else
-      cmd_exec("chmod #{mode.to_s(8)} '#{path}'")
+      create_process('chmod', args: [mode.to_s(8), path])
     end
   end
 
@@ -740,6 +740,7 @@ module Msf::Post::File
     else
       file_mode = 'Create'
     end
+    file_name = file_name.gsub("'","''")
     pwsh_code = <<~PSH
       try {
       $encoded='#{encoded_chunk}';
@@ -911,7 +912,7 @@ protected
       success = _win_ansi_write_file(b64_filename, b64_data, chunk_size)
       return false unless success
       vprint_status("Uploaded Base64-encoded file. Decoding using certutil")
-      success = _shell_command_with_success_code("certutil -f -decode #{b64_filename} #{file_name}")
+      success = _shell_process_with_success_code('certutil', ['-f', '-decode', b64_filename, file_name])
       return false unless success
     rescue ::Exception => e
       print_error("Exception while running #{__method__}: #{e}")
@@ -937,10 +938,10 @@ protected
       success = _win_ansi_write_file(b64_filename, b64_data, chunk_size)
       return false unless success
       vprint_status("Uploaded Base64-encoded file. Decoding using certutil")
-      success = _shell_command_with_success_code("certutil -decode #{b64_filename} #{tmp_filename}")
+      success = _shell_process_with_success_code('certutil', ['-decode', b64_filename, tmp_filename])
       return false unless success
       vprint_status("Certutil succeeded. Appending using copy")
-      success = _shell_command_with_success_code("copy /b #{file_name}+#{tmp_filename} #{file_name}")
+      success = _shell_process_with_success_code('copy', ['/b', "#{file_name}+#{tmp_filename}", file_name])
       return false unless success
     rescue ::Exception => e
       print_error("Exception while running #{__method__}: #{e}")
@@ -980,7 +981,7 @@ protected
     # Short-circuit an empty string. The : builtin is part of posix
     # standard and should theoretically exist everywhere.
     if data.empty?
-      return _shell_command_with_success_code(": #{redirect} #{file_name}")
+      return _shell_command_with_success_code(": #{redirect} #{session.escape_arg(file_name)}")
     end
 
     d = data.dup
@@ -1081,7 +1082,7 @@ protected
     # The first command needs to use the provided redirection for either
     # appending or truncating.
     cmd = command.sub('CONTENTS') { chunks.shift }
-    succeeded = _shell_command_with_success_code("#{cmd} #{redirect} \"#{file_name}\"")
+    succeeded = _shell_command_with_success_code("#{cmd} #{redirect} #{session.escape_arg(file_name)}")
     return false unless succeeded
 
     # After creating/truncating or appending with the first command, we
@@ -1090,7 +1091,7 @@ protected
       vprint_status("Next chunk is #{chunk.length} bytes")
       cmd = command.sub('CONTENTS') { chunk }
 
-      succeeded = _shell_command_with_success_code("#{cmd} >> '#{file_name}'")
+      succeeded = _shell_command_with_success_code("#{cmd} >> #{session.escape_arg(file_name)}")
       unless succeeded
         print_warning("Write partially succeeded then failed. May need to manually clean up #{file_name}")
         return false
@@ -1107,6 +1108,15 @@ protected
     return result&.include?(token)
   end
 
+  def _shell_process_with_success_code(executable, args)
+    cmd = session.to_cmd([executable] + args)
+    token = "_#{::Rex::Text.rand_text_alpha(32)}"
+    result = session.shell_command_token("#{cmd} && echo #{token}")
+
+    return result&.include?(token)
+  end
+
+
   #
   # Calculate the maximum line length for a unix shell.
   #
